@@ -20,7 +20,6 @@ package org.apache.hadoop.fs.swift.http;
 
 import org.apache.commons.httpclient.DefaultHttpMethodRetryHandler;
 import org.apache.commons.httpclient.Header;
-import org.apache.commons.httpclient.HeaderElement;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpHost;
 import org.apache.commons.httpclient.HttpMethod;
@@ -41,26 +40,16 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.swift.auth.ApiKeyAuthenticationRequest;
 import org.apache.hadoop.fs.swift.auth.ApiKeyCredentials;
 import org.apache.hadoop.fs.swift.auth.AuthenticationRequest;
-import org.apache.hadoop.fs.swift.auth.AuthenticationRequestV2;
-import org.apache.hadoop.fs.swift.auth.AuthenticationRequestV3;
 import org.apache.hadoop.fs.swift.auth.AuthenticationRequestWrapper;
 import org.apache.hadoop.fs.swift.auth.AuthenticationResponse;
-import org.apache.hadoop.fs.swift.auth.AuthenticationResponseV3;
 import org.apache.hadoop.fs.swift.auth.AuthenticationWrapper;
-import org.apache.hadoop.fs.swift.auth.AuthenticationWrapperV3;
 import org.apache.hadoop.fs.swift.auth.KeyStoneAuthRequest;
 import org.apache.hadoop.fs.swift.auth.KeystoneApiKeyCredentials;
 import org.apache.hadoop.fs.swift.auth.PasswordAuthenticationRequest;
-import org.apache.hadoop.fs.swift.auth.PasswordAuthenticationRequestV3;
-import org.apache.hadoop.fs.swift.auth.TokenAuthenticationRequestV3;
-import org.apache.hadoop.fs.swift.auth.TrustAuthenticationRequest;
 import org.apache.hadoop.fs.swift.auth.PasswordCredentials;
-import org.apache.hadoop.fs.swift.auth.PasswordCredentialsV3;
 import org.apache.hadoop.fs.swift.auth.entities.AccessToken;
 import org.apache.hadoop.fs.swift.auth.entities.Catalog;
-import org.apache.hadoop.fs.swift.auth.entities.CatalogV3;
 import org.apache.hadoop.fs.swift.auth.entities.Endpoint;
-import org.apache.hadoop.fs.swift.auth.entities.EndpointV3;
 import org.apache.hadoop.fs.swift.exceptions.SwiftAuthenticationFailedException;
 import org.apache.hadoop.fs.swift.exceptions.SwiftBadRequestException;
 import org.apache.hadoop.fs.swift.exceptions.SwiftConfigurationException;
@@ -141,16 +130,6 @@ public final class SwiftRestClient {
    */
   private final String password;
 
-  /**
-   * trust id
-   */
-  private final String trust_id;
-
-  /**
-   * user's domain name
-   */
-  private final String domain_name;
-
   /**
    * user api key
    */
@@ -489,8 +468,6 @@ public final class SwiftRestClient {
     String stringAuthUri = getOption(props, SWIFT_AUTH_PROPERTY);
     username = getOption(props, SWIFT_USERNAME_PROPERTY);
     password = props.getProperty(SWIFT_PASSWORD_PROPERTY);
-    trust_id = props.getProperty(SWIFT_TRUST_ID_PROPERTY);
-    domain_name = props.getProperty(SWIFT_DOMAIN_NAME_PROPERTY);
     apiKey = props.getProperty(SWIFT_APIKEY_PROPERTY);
     //optional
     region = props.getProperty(SWIFT_REGION_PROPERTY);
@@ -502,38 +479,25 @@ public final class SwiftRestClient {
     String isPubProp = props.getProperty(SWIFT_PUBLIC_PROPERTY, "false");
     usePublicURL = "true".equals(isPubProp);
     authEndpointPrefix = getOption(props, SWIFT_AUTH_ENDPOINT_PREFIX);
-    boolean isV3 = stringAuthUri.contains("/v3/auth/tokens");
 
-    if (apiKey == null && password == null) {
-      throw new SwiftConfigurationException(
-                  "Configuration for " + filesystemURI +" must contain either "
-                  + SWIFT_PASSWORD_PROPERTY + " or "
-                  + SWIFT_APIKEY_PROPERTY);
-    }
-    //create the (reusable) authentication request
-    if (isV3) {
-      if (trust_id == null) {
-        if (password != null) {
-          authRequest = new PasswordAuthenticationRequestV3(tenant,
-                  new PasswordCredentialsV3(username, password, domain_name));
-        } else {
-          authRequest = new TokenAuthenticationRequestV3(apiKey);
+        if (apiKey == null && password == null) {
+            throw new SwiftConfigurationException(
+                    "Configuration for " + filesystemURI +" must contain either "
+                            + SWIFT_PASSWORD_PROPERTY + " or "
+                            + SWIFT_APIKEY_PROPERTY);
         }
-      } else {
-        authRequest = new TrustAuthenticationRequest(
-                new PasswordCredentialsV3(username, password, domain_name),
-                trust_id);
-      }
-    } else {
-      if (password != null) {
-        authRequest = new PasswordAuthenticationRequest(tenant,
-                new PasswordCredentials(username, password));
-      } else {
-        authRequest = new ApiKeyAuthenticationRequest(tenant,
-                new ApiKeyCredentials(username, apiKey));
-        keystoneAuthRequest = new KeyStoneAuthRequest(tenant,
-                new KeystoneApiKeyCredentials(username, apiKey));
-      }
+        //create the (reusable) authentication request
+        if (password != null) {
+            authRequest = new PasswordAuthenticationRequest(tenant,
+                    new PasswordCredentials(
+                            username,
+                            password));
+        } else {
+            authRequest = new ApiKeyAuthenticationRequest(tenant,
+                    new ApiKeyCredentials(
+                            username, apiKey));
+            keystoneAuthRequest = new KeyStoneAuthRequest(tenant,
+                    new KeystoneApiKeyCredentials(username, apiKey));
     }
     locationAware = "true".equals(
       props.getProperty(SWIFT_LOCATION_AWARE_PROPERTY, "false"));
@@ -908,7 +872,6 @@ public final class SwiftRestClient {
    * Find objects in a directory
    *
    * @param path path prefix
-   * @param addTrailingSlash should a trailing slash be added if there isn't one
    * @param requestHeaders optional request headers
    * @return byte[] file data or null if the object was not found
    * @throws IOException on IO Faults
@@ -917,7 +880,6 @@ public final class SwiftRestClient {
    */
   public byte[] listDeepObjectsInDirectory(SwiftObjectPath path,
                                            boolean listDeep,
-                                           boolean addTrailingSlash,
                                        final Header... requestHeaders)
           throws IOException {
     preRemoteCommand("listDeepObjectsInDirectory");
@@ -929,7 +891,7 @@ public final class SwiftRestClient {
     if (object.startsWith("/")) {
       object = object.substring(1);
     }
-    if (addTrailingSlash && !object.endsWith("/")) {
+    if (!object.endsWith("/")) {
       object = object.concat("/");
     }
 
@@ -1208,23 +1170,12 @@ public final class SwiftRestClient {
 
     @Override
     public AccessToken extractResult(AuthPostMethod method) throws IOException {
-
       //initial check for failure codes leading to authentication failures
       if (method.getStatusCode() == SC_BAD_REQUEST) {
         throw new SwiftAuthenticationFailedException(
           authenticationRequest.toString(), "POST", authUri, method);
       }
 
-      if (authenticationRequest instanceof AuthenticationRequestV2) {
-        return extractResultV2(method);
-      } else {
-        return extractResultV3(method);
-      }
-
-    }
-
-    AccessToken extractResultV2(AuthPostMethod method) throws IOException {
-
       final AuthenticationResponse access =
         JSONUtil.toObject(method.getResponseBodyAsString(),
                           AuthenticationWrapper.class).getAccess();
@@ -1318,76 +1269,6 @@ public final class SwiftRestClient {
       createDefaultContainer();
       return accessToken;
     }
-
-    AccessToken extractResultV3(AuthPostMethod method) throws IOException {
-
-      final AuthenticationResponseV3 response =
-        JSONUtil.toObject(method.getResponseBodyAsString(),
-                          AuthenticationWrapperV3.class).getToken();
-
-      URI endpointURI = null;
-      for (CatalogV3 catalog : response.getCatalog()) {
-        String name = catalog.getName();
-        String type = catalog.getType();
-
-        if (!name.equals(SERVICE_CATALOG_SWIFT)
-            && !name.equals(SERVICE_CATALOG_CLOUD_FILES)
-            && !type.equals(SERVICE_CATALOG_OBJECT_STORE)) {
-          continue;
-        }
-
-        for (EndpointV3 endpoint : catalog.getEndpoints()) {
-          if (region != null && !endpoint.getRegion().equals(region)) {
-            continue;
-          }
-          if ((usePublicURL && "public".equals(endpoint.getInterface()))
-              || (!usePublicURL && "internal".equals(endpoint.getInterface()))) {
-            endpointURI = endpoint.getUrl();
-            break;
-          }
-        }
-      }
-      if (endpointURI == null) {
-        String message = "Could not find swift service from auth URL "
-                         + authUri
-                         + " and region '" + region + "'.";
-        throw new SwiftInvalidResponseException(message,
-                                                SC_OK,
-                                                "authenticating",
-                                                authUri);
-
-      }
-
-      AccessToken token = new AccessToken();
-      final Header token_header = method.getResponseHeader("X-Subject-Token");
-      if (token_header == null) {
-        throw new SwiftException("invalid Keystone response");
-      }
-      token.setId(token_header.getValue());
-      token.setExpires(response.getExpires_at());
-      token.setTenant(response.getProject());
-
-      URI objectLocation = null;
-      String path = getAuthEndpointPrefix() + token.getTenant().getId();
-      try {
-        objectLocation = new URI(endpointURI.getScheme(),
-                                 null,
-                                 endpointURI.getHost(),
-                                 endpointURI.getPort(),
-                                 path,
-                                 null,
-                                 null);
-      } catch (URISyntaxException e) {
-        throw new SwiftException("object endpoint URI is incorrect: "
-                                 + endpointURI
-                                 + " + " + path,
-                                 e);
-      }
-
-      setAuthDetails(endpointURI, objectLocation, token);
-      createDefaultContainer();
-      return token;
-    }
   }
 
   private StringRequestEntity getAuthenticationRequst(AuthenticationRequest authenticationRequest)
@@ -1813,10 +1694,10 @@ public final class SwiftRestClient {
    * @param accessToken access token
    * @throws SwiftInternalStateException if the client is not yet authenticated
    */
-  private void setAuthToken(HttpMethod method, AccessToken accessToken)
+  private void setAuthToken(HttpMethodBase method, AccessToken accessToken)
       throws SwiftInternalStateException {
     checkNotNull(accessToken,"Not authenticated");
-    method.setRequestHeader(HEADER_AUTH_KEY, accessToken.getId());
+    method.addRequestHeader(HEADER_AUTH_KEY, accessToken.getId());
   }
 
   /**
@@ -1868,7 +1749,7 @@ public final class SwiftRestClient {
         LOG.debug("Reauthenticating");
       }
       //re-auth, this may recurse into the same dir
-      setAuthToken(method, authenticate());
+      authenticate();
       if (LOG.isDebugEnabled()) {
         LOG.debug("Retrying original request");
       }
